import time
from typing import List
from uuid import uuid4

import pytest

import examples.cameras as cameras_example
import kognic.io.client as IOC
from examples.utils import wait_for_scene_job
from kognic.io.model import InputStatus
from kognic.io.model.projects import Project
from tests.utils import TestProjects


@pytest.mark.integration  # TODO: Remove this mark once the integration tests are ready
class TestDuplicateInputsValidation:
    """
    Tests that validation of duplication of inputs works correctly
    """

    @staticmethod
    def filter_cameras_project(projects: List[Project]):
        return next(p for p in projects if p.project == TestProjects.CamerasProject)

    def test_sync_validation(self, client: IOC.KognicIOClient):
        projects = client.project.get_projects()
        project = self.filter_cameras_project(projects).project
        external_id = f"duplicate-inputs-sync-validation-{uuid4()}"
        scene = cameras_example.build_scene(external_id=external_id)

        # Create first input
        resp = client.cameras.create(scene, project=project, dryrun=False)
        wait_for_scene_job(client=client, scene_uuid=resp.scene_uuid)

        # Create second input
        with pytest.raises(RuntimeError) as excinfo:
            client.cameras.create(scene, project=project, dryrun=False)
        assert "Duplicate inputs for external id" in str(excinfo.value)

    def test_async_validation(self, client: IOC.KognicIOClient):
        projects = client.project.get_projects()
        project = self.filter_cameras_project(projects).project
        external_id = f"duplicate-inputs-async-validation-{uuid4()}"
        scene = cameras_example.build_scene(external_id=external_id)

        # Create both inputs
        resp1 = client.cameras.create(scene, project=project, dryrun=False)
        resp2 = client.cameras.create(scene, project=project, dryrun=False)

        # Wait
        status1 = wait_for_scene_job(client=client, scene_uuid=resp1.scene_uuid)
        status2 = wait_for_scene_job(client=client, scene_uuid=resp2.scene_uuid)

        assert {status1, status2} == {InputStatus.Created, InputStatus.Failed}  # One scene should be created, the other should fail

        failed_scene_uuid = resp1.scene_uuid if status1 == InputStatus.Failed else resp2.scene_uuid
        failed_scene = client.scene.get_scenes_by_uuids(scene_uuids=[failed_scene_uuid])[0]
        assert "Duplicate inputs for external id" in failed_scene.error_message
